import React from 'react'
import PropTypes from 'prop-types'

class Content extends React.Component {
  static defaultStyles = {
    position: 'absolute',
    top: '100px',
    left: '100px',
    right: '100px',
    bottom: '100px',
    background: '#fff',
    overflow: 'auto',
    WebkitOverflowScrolling: 'touch',
    outline: 'none',
    padding: '20px',
    border: '1px solid #ddd'
  }

  static defaultProps = {
    closeOnEsc: false
  }

  static propTypes = {
    className: PropTypes.string,
    style: PropTypes.object,
    children: PropTypes.node,
    closeOnEsc: PropTypes.bool,
    onRequestClose: PropTypes.func.isRequired
  }

  get style() {
    const defaultStyles = Content.defaultStyles
    const styles = this.props.style

    if (!styles) {
      return defaultStyles
    }

    return Object.assign({}, defaultStyles, styles)
  }

  render() {
    const { children, className } = this.props

    return (
      <div
        ref={this.refNode}
        tabIndex="-1"
        style={this.style}
        onKeyDown={this.handleKeyDown}
        className={className}
      >
        {children}
      </div>
    )
  }

  refNode = node => {
    this.node = node
  }

  contentHasFocus = () => {
    return (
      document.activeElement === this.node ||
      this.node.contains(document.activeElement)
    )
  }

  handleKeyDown = event => {
    if (this.props.closeOnEsc && event.keyCode === 27) {
      if (this.contentHasFocus()) {
        event.stopPropagation()

        this.props.onRequestClose(event)
      }
    }
  }
}

export default Content
